# This data structure provides information about each QTL analysis to
# perform. Each list element of "analyses" is a list with the
# following list elements: "pheno", the phenotype or trait to map;
# "cov", the covariates to include in the regression model of the
# phenotype; "outliers", specification of the data points to remove
# according to the residuals after removing the effects of the
# covariates; and "file", the RData file where the results will be
# saved.

analyses <- list(

# Skull analyses
sPC1 = list(pheno="sPC1",cov=NULL, outliers=NULL, file="gwscan.skullPC1.RData" ),
sPC2 = list(pheno="sPC2",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.skullPC2.RData" ),
sPC3 = list(pheno="sPC3",cov=NULL, outliers=function (x) x < (-3 ) & x > (3), file="gwscan.skullPC3.RData" ),
sPC4 = list(pheno="sPC4",cov=NULL, outliers=NULL, file="gwscan.skullPC4.RData" ),
sPC5 = list(pheno="sPC5",cov=NULL, outliers=NULL, file="gwscan.skullPC5.RData" ),
sPC6 = list(pheno="sPC6",cov=NULL, outliers=function (x) x > (3), file="gwscan.skullPC6.RData" ),
sPC7 = list(pheno="sPC7",cov=NULL, outliers=function (x) x < (-3.5), file="gwscan.skullPC7.RData" ),
sPC8 = list(pheno="sPC8",cov=NULL, outliers=function (x) x > (3.5 ), file="gwscan.skullPC8.RData" ),
sPC9 = list(pheno="sPC9",cov=NULL, outliers=function (x) x < (-3.5), file="gwscan.skullPC9.RData" ),
sPC10 = list(pheno="sPC10",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.skullPC10.RData" ),
sPC11 = list(pheno="sPC11",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.skullPC11.RData" ),
sPC12 = list(pheno="sPC12",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.skullPC12.RData" ),
sPC13 = list(pheno="sPC13",cov=NULL, outliers=function (x) x > (4 ), file="gwscan.skullPC13.RData" ),
sPC14 = list(pheno="sPC14",cov=NULL, outliers=NULL, file="gwscan.skullPC14.RData" ),
sPC15 = list(pheno="sPC15",cov=NULL, outliers=NULL, file="gwscan.skullPC15.RData" ),
sPC16 = list(pheno="sPC16",cov=NULL, outliers=NULL, file="gwscan.skullPC16.RData" ),
sPC17 = list(pheno="sPC17",cov=NULL, outliers=NULL, file="gwscan.skullPC17.RData" ),
sPC18 = list(pheno="sPC18",cov=NULL, outliers=function (x) x > (4 ), file="gwscan.skullPC18.RData" ),
sPC19 = list(pheno="sPC19",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.skullPC19.RData" ),
sPC20 = list(pheno="sPC20",cov=NULL, outliers=function (x) x > (3 ) & x < (-3), file="gwscan.skullPC20.RData" ),
sPC21 = list(pheno="sPC21",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.skullPC21.RData" ),
sPC22 = list(pheno="sPC22",cov=NULL, outliers=NULL, file="gwscan.skullPC22.RData" ),

sCS = list(pheno="sCS",cov=NULL, outliers=function (x) x < (-3), file="gwscan.skullCS.RData" ),

# Mandible analyses
mPC1 = list(pheno="mPC1",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.mandmPC1.RData" ),
mPC2 = list(pheno="mPC2",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.mandmPC2.RData" ),
mPC3 = list(pheno="mPC3",cov=NULL, outliers=NULL, file="gwscan.mandmPC3.RData" ),
mPC4 = list(pheno="mPC4",cov=NULL, outliers=function (x) x > (3) & x < (-3), file="gwscan.mandmPC4.RData" ),
mPC5 = list(pheno="mPC5",cov=NULL, outliers=function (x) x > (4 ), file="gwscan.mandmPC5.RData" ),
mPC6 = list(pheno="mPC6",cov=NULL, outliers=function (x) x < (-4 ), file="gwscan.mandmPC6.RData" ),
mPC7 = list(pheno="mPC7",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.mandmPC7.RData" ),
mPC8 = list(pheno="mPC8",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.mandmPC8.RData" ),
mPC9 = list(pheno="mPC9",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.mandmPC9.RData" ),
mPC10 = list(pheno="mPC10",cov=NULL, outliers=function (x) x < (-3 ), file="gwscan.mandmPC10.RData" ),
mPC11 = list(pheno="mPC11",cov=NULL, outliers=NULL, file="gwscan.mandmPC11.RData" ),
mPC12 = list(pheno="mPC12",cov=NULL, outliers=NULL, file="gwscan.mandmPC12.RData" ),
mPC13 = list(pheno="mPC13",cov=NULL, outliers=function (x) x < (-3 ) & x > (3), file="gwscan.mandmPC13.RData" ),
mPC14 = list(pheno="mPC14",cov=NULL, outliers=function (x) x < (-3 ) & x > (3), file="gwscan.mandmPC14.RData" ),
mPC15 = list(pheno="mPC15",cov=NULL, outliers=NULL, file="gwscan.mandmPC15.RData" ),
mPC16 = list(pheno="mPC16",cov=NULL, outliers=function (x) x < (-3 ) & x > (3), file="gwscan.mandmPC16.RData" ),
mPC17 = list(pheno="mPC17",cov=NULL, outliers=function (x) x < (-3), file="gwscan.mandmPC17.RData" ),
mPC18 = list(pheno="mPC18",cov=NULL, outliers=NULL, file="gwscan.mandmPC18.RData" ),
mPC19 = list(pheno="mPC19",cov=NULL, outliers=NULL, file="gwscan.mandmPC19.RData" ),
mPC20 = list(pheno="mPC20",cov=NULL, outliers=function (x) x > (3 ), file="gwscan.mandmPC20.RData" ),
mPC21 = list(pheno="mPC21",cov=NULL, outliers=function (x) x > (4 ), file="gwscan.mandmPC21.RData" ),

mCS = list(pheno="mCS",cov=NULL, outliers=function (x) x < (-4), file="gwscan.mandmCS.RData" )
)
